@@ -21,28 +21,29 @@
 // Own
 #include "Pty.h"
 
+#include "konsoledebug.h"
+
 // System
 #include <termios.h>
 #include <signal.h>
 
 // Qt
-#include <QtCore/QStringList>
+#include <QStringList>
 #include <qplatformdefs.h>
 
 // KDE
-#include <QDebug>
 #include <KPtyDevice>
 
 using Konsole::Pty;
 
-Pty::Pty(int masterFd, QObject* aParent)
-    : KPtyProcess(masterFd, aParent)
+Pty::Pty(int masterFd, QObject *aParent) :
+    KPtyProcess(masterFd, aParent)
 {
     init();
 }
 
-Pty::Pty(QObject* aParent)
-    : KPtyProcess(aParent)
+Pty::Pty(QObject *aParent) :
+    KPtyProcess(aParent)
 {
     init();
 }
@@ -50,10 +51,10 @@ Pty::Pty(QObject* aParent)
 void Pty::init()
 {
     _windowColumns = 0;
-    _windowLines   = 0;
-    _eraseChar     = 0;
-    _xonXoff       = true;
-    _utf8          = true;
+    _windowLines = 0;
+    _eraseChar = 0;
+    _xonXoff = true;
+    _utf8 = true;
 
     setEraseChar(_eraseChar);
     setFlowControlEnabled(_xonXoff);
@@ -64,20 +65,19 @@ void Pty::init()
     setUseUtmp(true);
     setPtyChannels(KPtyProcess::AllChannels);
 
-    connect(pty(), &KPtyDevice::readyRead , this , &Konsole::Pty::dataReceived);
+    connect(pty(), &KPtyDevice::readyRead, this, &Konsole::Pty::dataReceived);
 }
 
-Pty::~Pty()
-{
-}
+Pty::~Pty() = default;
 
-void Pty::sendData(const QByteArray& data)
+void Pty::sendData(const QByteArray &data)
 {
-    if (data.isEmpty())
+    if (data.isEmpty()) {
         return;
+    }
 
-    if (!pty()->write(data.constData(), data.length())) {
-        qWarning() << "Could not send input data to terminal process.";
+    if (pty()->write(data.constData()) == -1) {
+        qCDebug(KonsoleDebug) << "Could not send input data to terminal process.";
         return;
     }
 }
@@ -85,6 +85,10 @@ void Pty::sendData(const QByteArray& data)
 void Pty::dataReceived()
 {
     QByteArray data = pty()->readAll();
+    if (data.isEmpty()) {
+        return;
+    }
+
     emit receivedData(data.constData(), data.count());
 }
 
@@ -93,8 +97,9 @@ void Pty::setWindowSize(int columns, int lines)
     _windowColumns = columns;
     _windowLines = lines;
 
-    if (pty()->masterFd() >= 0)
+    if (pty()->masterFd() >= 0) {
         pty()->setWinSize(lines, columns);
+    }
 }
 
 QSize Pty::windowSize() const
@@ -109,13 +114,15 @@ void Pty::setFlowControlEnabled(bool enable)
     if (pty()->masterFd() >= 0) {
         struct ::termios ttmode;
         pty()->tcGetAttr(&ttmode);
-        if (enable)
+        if (enable) {
             ttmode.c_iflag |= (IXOFF | IXON);
-        else
+        } else {
             ttmode.c_iflag &= ~(IXOFF | IXON);
+        }
 
-        if (!pty()->tcSetAttr(&ttmode))
-            qWarning() << "Unable to set terminal attributes.";
+        if (!pty()->tcSetAttr(&ttmode)) {
+            qCDebug(KonsoleDebug) << "Unable to set terminal attributes.";
+        }
     }
 }
 
@@ -124,10 +131,10 @@ bool Pty::flowControlEnabled() const
     if (pty()->masterFd() >= 0) {
         struct ::termios ttmode;
         pty()->tcGetAttr(&ttmode);
-        return ttmode.c_iflag & IXOFF &&
-               ttmode.c_iflag & IXON;
+        return ((ttmode.c_iflag & IXOFF) != 0u)
+               && ((ttmode.c_iflag & IXON) != 0u);
     } else {
-        qWarning() << "Unable to get flow control status, terminal not connected.";
+        qCDebug(KonsoleDebug) << "Unable to get flow control status, terminal not connected.";
         return _xonXoff;
     }
 }
@@ -140,13 +147,15 @@ void Pty::setUtf8Mode(bool enable)
     if (pty()->masterFd() >= 0) {
         struct ::termios ttmode;
         pty()->tcGetAttr(&ttmode);
-        if (enable)
+        if (enable) {
             ttmode.c_iflag |= IUTF8;
-        else
+        } else {
             ttmode.c_iflag &= ~IUTF8;
+        }
 
-        if (!pty()->tcSetAttr(&ttmode))
-            qWarning() << "Unable to set terminal attributes.";
+        if (!pty()->tcSetAttr(&ttmode)) {
+            qCDebug(KonsoleDebug) << "Unable to set terminal attributes.";
+        }
     }
 #else
     Q_UNUSED(enable);
@@ -162,8 +171,9 @@ void Pty::setEraseChar(char eChar)
         pty()->tcGetAttr(&ttmode);
         ttmode.c_cc[VERASE] = eChar;
 
-        if (!pty()->tcSetAttr(&ttmode))
-            qWarning() << "Unable to set terminal attributes.";
+        if (!pty()->tcSetAttr(&ttmode)) {
+            qCDebug(KonsoleDebug) << "Unable to set terminal attributes.";
+        }
     }
 }
 
@@ -174,12 +184,12 @@ char Pty::eraseChar() const
         pty()->tcGetAttr(&ttyAttributes);
         return ttyAttributes.c_cc[VERASE];
     } else {
-        qWarning() << "Unable to get erase char attribute, terminal not connected.";
+        qCDebug(KonsoleDebug) << "Unable to get erase char attribute, terminal not connected.";
         return _eraseChar;
     }
 }
 
-void Pty::setInitialWorkingDirectory(const QString& dir)
+void Pty::setInitialWorkingDirectory(const QString &dir)
 {
     QString pwd = dir;
 
@@ -192,17 +202,18 @@ void Pty::setInitialWorkingDirectory(const QString& dir)
     setWorkingDirectory(pwd);
 
     // setting PWD to "." will cause problem for bash & zsh
-    if (pwd != ".")
-        setEnv("PWD", pwd);
+    if (pwd != QLatin1String(".")) {
+        setEnv(QStringLiteral("PWD"), pwd);
+    }
 }
 
-void Pty::addEnvironmentVariables(const QStringList& environmentVariables)
+void Pty::addEnvironmentVariables(const QStringList &environmentVariables)
 {
     bool isTermEnvAdded = false;
 
-    foreach(const QString& pair, environmentVariables) {
+    foreach (const QString &pair, environmentVariables) {
         // split on the first '=' character
-        const int separator = pair.indexOf('=');
+        const int separator = pair.indexOf(QLatin1Char('='));
 
         if (separator >= 0) {
             QString variable = pair.left(separator);
@@ -210,7 +221,7 @@ void Pty::addEnvironmentVariables(const QStringList& environmentVariables)
 
             setEnv(variable, value);
 
-            if (variable == "TERM") {
+            if (variable == QLatin1String("TERM")) {
                 isTermEnvAdded = true;
             }
         }
@@ -218,13 +229,12 @@ void Pty::addEnvironmentVariables(const QStringList& environmentVariables)
 
     // extra safeguard to make sure $TERM is always set
     if (!isTermEnvAdded) {
-        setEnv("TERM", "xterm-256color");
+        setEnv(QStringLiteral("TERM"), QStringLiteral("xterm-256color"));
     }
 }
 
-int Pty::start(const QString& programName,
-               const QStringList& programArguments,
-               const QStringList& environmentList)
+int Pty::start(const QString &programName, const QStringList &programArguments,
+               const QStringList &environmentList)
 {
     clearProgram();
 
@@ -247,7 +257,8 @@ int Pty::start(const QString& programName,
     // does not have a translation for
     //
     // BR:149300
-    setEnv("LANGUAGE", QString(), false /* do not overwrite existing value if any */);
+    setEnv(QStringLiteral("LANGUAGE"), QString(),
+           false /* do not overwrite existing value if any */);
 
     KProcess::start();
 
@@ -264,15 +275,15 @@ void Pty::setWriteable(bool writeable)
     if (QT_STAT(pty()->ttyName(), &sbuf) == 0) {
         if (writeable) {
             if (::chmod(pty()->ttyName(), sbuf.st_mode | S_IWGRP) < 0) {
-                qWarning() << "Could not set writeable on "<<pty()->ttyName();
+                qCDebug(KonsoleDebug) << "Could not set writeable on "<<pty()->ttyName();
             }
         } else {
             if (::chmod(pty()->ttyName(), sbuf.st_mode & ~(S_IWGRP | S_IWOTH)) < 0) {
-                qWarning() << "Could not unset writeable on "<<pty()->ttyName();
+                qCDebug(KonsoleDebug) << "Could not unset writeable on "<<pty()->ttyName();
             }
         }
     } else {
-        qWarning() << "Could not stat "<<pty()->ttyName();
+        qCDebug(KonsoleDebug) << "Could not stat "<<pty()->ttyName();
     }
 }
 
@@ -284,14 +295,14 @@ void Pty::closePty()
 void Pty::sendEof()
 {
     if (pty()->masterFd() < 0) {
-        qWarning() << "Unable to get eof char attribute, terminal not connected.";
+        qCDebug(KonsoleDebug) << "Unable to get eof char attribute, terminal not connected.";
         return;
     }
     struct ::termios ttyAttributes;
     pty()->tcGetAttr(&ttyAttributes);
     char eofChar = ttyAttributes.c_cc[VEOF];
-    if (!pty()->write(QByteArray(1, eofChar))) {
-        qWarning() << "Unable to send EOF";
+    if (pty()->write(QByteArray(1, eofChar)) == -1) {
+        qCDebug(KonsoleDebug) << "Unable to send EOF";
     }
 
     pty()->waitForBytesWritten();
@@ -324,7 +335,7 @@ void Pty::setupChildProcess()
     sigemptyset(&action.sa_mask);
     action.sa_handler = SIG_DFL;
     action.sa_flags = 0;
-    for (int signal = 1; signal < NSIG; signal++)
+    for (int signal = 1; signal < NSIG; signal++) {
         sigaction(signal, &action, 0);
+    }
 }
-
